# ansar-connect

The **ansar-connect** library implements clear and concise network messaging for a wide range
of networking requirements. From multi-processing within a single host through to messaging
beween different LANs on the Internet. There is a single send method that does it all.

## Features

- Implements full-duplex, network messaging over asynchronous sockets,
- Inherits the data sophistication of **ansar.encode**,
- Seamlessly extends the asynchronous runtime from **ansar.create**, to span local and wide-area networks.
